@@ -657,7 +657,7 @@ class Row:
         self.__data = data
     def get(self, name):
         if self.offsets[name]['count'] > 1:
-            log.info(color.cyan('Row offset %s'), name)
+            #log.info(color.cyan('Row offset %s'), name)
             #print(name, self.offsets[name], self.__data[self.offsets[name]['position']:self.offsets[name]['position']+self.offsets[name]['count']])
             return self.__data[self.offsets[name]['position']:self.offsets[name]['position']+self.offsets[name]['count']]
         return self.__data[self.offsets[name]['position']]
